@@ -26,8 +26,8 @@ def knnAccuracy(embedding, labeldict, k=5):
     labels = embedding.index.to_series().map(labeldict)
     kNN    = KNeighborsClassifier(k+1)
     kNN.fit(embedding.values, labels)
-    estmte = kNN.predict(embedding.values)
-    return accuracy_score(estmte, labels)*(k+1)/k-1/k, estate
+    estimate = kNN.predict(embedding.values)
+    return accuracy_score(estimate, labels)*(k+1)/k-1/k, estimate
 
 def LeidenClusters(D, labeldict, k=5, res = 0.08, seed=None):
     kNNgraph = kneighbors_graph(D, k)
